package Locale::CLDR::Ca::Any v0.25.0;
# This file auto generated
#	on Mon 21 Apr 10:33:03 pm GMT

use v5.18;
use mro 'c3';

use Moose;

extends('Locale::CLDR::Ca');

no Moose;
__PACKAGE__->meta->make_immutable;
